# otl-normalizer

This crate converts OpenType layout subtables to a normalized representation,
suitable for comparison in a text diff.

It is part of the [`fontc`] project, and is used to test font compilation as
well as to compare the output of different compiler toolchains.


[`fontc`]: https://github.com/googlefonts/fontc
